@@ -61,8 +61,7 @@ static unsigned char itoa64[] =         /* 0 ... 63 => ascii - 64 */
 
 static void to64(char *s, long v, int n)
 {
-	while (--n >= 0)
-	{
+	while (--n >= 0) {
 		*s++ = itoa64[v&0x3f];
 		v >>= 6;
 	}
@@ -175,8 +174,7 @@ ScriptBinder(run)
 {
 	char path[128];
 
-	if(*Script::var_prefix != '.')
-	{
+	if(*Script::var_prefix != '.') {
 		snprintf(path, sizeof(path), "%s" PRE_MAKE,
 			Script::var_prefix);
 		Dir::create(path);
@@ -287,16 +285,13 @@ void AuthorizeThread::run(void)
 	time_t now;
 
 	fp = ::fopen(path, "r");
-	if(!fp)
-	{
+	if(!fp) {
 		exitEvent("authorize:missing");
 		exit("authorize-missing");
 	}
 
-	while(fp)
-	{
-		if(!fgets(path, sizeof(path), fp) || feof(fp))
-		{
+	while(fp) {
+		if(!fgets(path, sizeof(path), fp) || feof(fp)) {
 			exitEvent("authorize:missing");
 			exit("authorize-missing");
 		}
@@ -304,8 +299,7 @@ void AuthorizeThread::run(void)
 		uid = strtok_r(path, ":\r\n", &tok);
 		if(!uid)
 			continue;
-		if(!stricmp(uid, user))
-		{
+		if(!stricmp(uid, user)) {
 			pwd = strtok_r(NULL, ":\r\n", &tok);
 			break;
 		}
@@ -321,8 +315,7 @@ void AuthorizeThread::run(void)
 	authlock.leave();
 #endif
 
-	if(!pass)
-	{
+	if(!pass) {
 		exitEvent("authorize:failed");
 		exit("authorize-failed");
 	}
@@ -350,17 +343,14 @@ void PasswordThread::run(void)
 	char *cp;
 
 	fp = ::fopen(path, "r+");
-	if(!fp)
-	{
+	if(!fp) {
 		exitEvent("password:missing");
 		exit("password-missing");
 	}
 
-	while(fp)
-	{
+	while(fp) {
 		fgetpos(fp, &fpos);
-		if(!fgets(path, sizeof(path), fp) || feof(fp))
-		{
+		if(!fgets(path, sizeof(path), fp) || feof(fp)) {
 			exitEvent("password:missing");
 			exit("password-missing");
 		}
@@ -369,8 +359,7 @@ void PasswordThread::run(void)
 		uid = strtok_r(path, ":\r\n", &tok);
 		if(!uid)
 			continue;
-		if(!stricmp(uid, user))
-		{
+		if(!stricmp(uid, user)) {
 			pwd = strtok_r(NULL, ":\r\n", &tok);
 			break;
 		}
@@ -379,8 +368,7 @@ void PasswordThread::run(void)
 #ifdef	WIN32
 	pass = NULL;
 #else
-	if(stricmp(pass, "-"))
-	{
+	if(stricmp(pass, "-")) {
 		authlock.enter();
 		pass = crypt(pass, pwd);
 		if(strcmp(pass, pwd))
@@ -389,8 +377,7 @@ void PasswordThread::run(void)
 	}
 #endif
 
-	if(!pass)
-	{
+	if(!pass) {
 		exitEvent("password:failed");
 		exit("password-failed");
 	}
@@ -420,8 +407,7 @@ void LookupThread::run(void)
 	if(key && *key)
 	        fp = ::fopen(path, "r");
 
-	if(!fp || !sym)
-	{
+	if(!fp || !sym) {
 		exitEvent("lookup:missing");
 		exit("lookup-missing");
 	}
@@ -447,8 +433,7 @@ void LookupThread::run(void)
 		if(strnicmp(key, tag, len))
 			continue;
 
-		if(prefix)
-		{
+		if(prefix) {
 			snprintf(buf, sizeof(buf), "%s/%s/%s",
 				Script::var_prefix, prefix, uid);
 			Dir::create(buf);
@@ -471,16 +456,14 @@ void IdentifyThread::run(void)
 	char *tok, *uid;
 
 	fp = ::fopen(path, "r");
-	if(!fp)
-	{
+	if(!fp) {
 		exitEvent("identify:missing");
 		exit("identify-missing");
 	}
 
 	for(;;)
 	{
-		if(!fgets(path, sizeof(path), fp) || feof(fp))
-		{
+		if(!fgets(path, sizeof(path), fp) || feof(fp)) {
 			exitEvent("identify:missing");
 			exit("identify-missing");
 		}
@@ -492,8 +475,7 @@ void IdentifyThread::run(void)
 		if(stricmp(uid, user))
 			continue;
 
-		if(prefix)
-		{
+		if(prefix) {
 			snprintf(path, sizeof(path), "%s/%s/%s",
 				Script::var_prefix, prefix, uid);
 			Dir::create(path);
@@ -521,8 +503,7 @@ bool UserauthMethods::scrAuthorize(void)
 	char *cp;
 	Symbol *sym = mapSymbol("script.authorize", 0);
 
-	if(!grp)
-	{
+	if(!grp) {
 		setString(buf, sizeof(buf), scr->name);
 		cp = strchr(buf, ':');
 		if(cp)
@@ -545,8 +526,7 @@ bool UserauthMethods::scrPassword(void)
 	const char *grp = getMember();
 	char *cp;
 
-	if(!grp)
-	{
+	if(!grp) {
 		setString(buf, sizeof(buf), scr->name);
 		cp = strchr(buf, ':');
 		if(cp)
@@ -567,8 +547,7 @@ bool UserauthMethods::scrLookup(void)
 	char *cp;
 	Symbol *sym;
 
-	if(!grp)
-	{
+	if(!grp) {
 		setString(buf, sizeof(buf), scr->name);
 		cp = strchr(buf, ':');
 		if(cp)
@@ -577,8 +556,7 @@ bool UserauthMethods::scrLookup(void)
 	}
 
 	sym = mapSymbol(getOption(), 0);
-	if(!sym)
-	{
+	if(!sym) {
 		error("target-missing");
 		return true;
 	}
@@ -598,8 +576,7 @@ bool UserauthMethods::scrIdentify(void)
 	const char *grp = getMember();
 	char *cp;
 
-	if(!grp)
-	{
+	if(!grp) {
 		setString(buf, sizeof(buf), scr->name);
 		cp = strchr(buf, ':');
 		if(cp)
