@@ -48,8 +48,7 @@ static Script::Define runtime[] = {
 
 void SQLBinder::down(void)
 {
-	if(hODBC)
-	{
+	if(hODBC) {
 		SQLFreeEnv(hODBC);
 		hODBC = NULL;
 	}
@@ -60,15 +59,13 @@ ScriptBinder("odbc")
 {
 	long err = SQLAllocHandle(SQL_HANDLE_ENV, SQL_NULL_HANDLE, &hODBC);
 
-	if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO)
-	{
+	if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO) {
 		slog.critical("odbc: cannot allocate");
 		return;
 	}
 
 	err = SQLSetEnvAttr(hODBC, SQL_ATTR_ODBC_VERSION, (void*)SQL_OV_ODBC3, 0);
-	if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO)
-	{
+	if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO) {
 		slog.critical("odbc: wrong version");
 		SQLFreeHandle(SQL_HANDLE_ENV, hODBC);
 		hODBC = NULL;
@@ -135,8 +132,7 @@ const char *SQLBinder::use(Line *line, ScriptImage *img)
 
 	img->setValue(name, dbname);
 	sql = (SQLDatabase *)img->getPointer(dbname);
-	if(!sql)
-	{
+	if(!sql) {
 		sql = new SQLDatabase(img, line);
 		img->setPointer(dbname, (void *)sql);
 	}
