@@ -72,8 +72,7 @@ void SQLThread::run(void)
 	char nbuf[12];
 	unsigned row = 0, len = 0;
 
-	if(!current->isConnected())
-	{
+	if(!current->isConnected()) {
 		lock();
 		interp->setSymbol("sql.error", "sql-connect-failed");
 		release();
@@ -86,8 +85,7 @@ void SQLThread::run(void)
 	release();
 
 	err = SQLAllocHandle(SQL_HANDLE_STMT, current->hdbc, &hstmt);
-	if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO)
-	{
+	if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO) {
 		hstmt = NULL;
 		SQLGetDiagRec(SQL_HANDLE_DBC, current->hdbc, 1,
 			stat, &err, errmsg, sizeof(errmsg), &mlen);
@@ -99,8 +97,7 @@ void SQLThread::run(void)
 	}
 
 	buf[0] = 0;
-	while(NULL != (opt = interp->getValue(NULL)))
-	{
+	while(NULL != (opt = interp->getValue(NULL))) {
 		Thread::yield();
 		addString(buf, sizeof(buf), opt);
 	}
@@ -108,8 +105,7 @@ void SQLThread::run(void)
 	Thread::yield();
 
 	err = SQLExecDirect(hstmt, (SQLCHAR *)buf, SQL_NTS);
-	if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO)
-	{
+	if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO) {
 		strcpy((char *)errmsg, "sql.");
 		SQLGetDiagRec(SQL_HANDLE_DBC, current->hdbc, 1,
 			stat, &err, errmsg, sizeof(errmsg) / sizeof(SQLCHAR), &mlen);
@@ -131,8 +127,7 @@ void SQLThread::run(void)
 	if(!sym)
 		exit(NULL);
 
-	while(row < count(sym))
-	{
+	while(row < count(sym)) {
 		err = SQLFetch(hstmt);
 	        if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO)
 			break;
@@ -145,8 +140,7 @@ void SQLThread::run(void)
 
 		col = 0;
 		len = 0;
-		while(col < cols && len < sizeof(buf) - 3)
-		{
+		while(col < cols && len < sizeof(buf) - 3) {
 			if(len)
 				buf[len++] = ',';
 			buf[len++] = '\'';
